==> k8s-cluster-api-0.0.6.crate: k8s-cluster-api-0.0.6/src/v1beta1/cluster/impls.rs <==
use std::fmt;

use super::*;

impl Cluster {
    pub fn phase(&self) -> ClusterPhase {
        self.status
            .as_ref()
            .map_or(ClusterPhase::Unknown, |status| status.phase())
    }

    pub fn conditions(&self) -> Option<&Conditions> {
        self.status
            .as_ref()
            .and_then(|status| status.conditions.as_ref())
    }

    pub fn conditions_mut(&mut self) -> Option<&mut Conditions> {
        self.status
            .as_mut()
            .and_then(|status| status.conditions.as_mut())
    }

    pub fn cluster_network(&self) -> Option<&ClusterNetwork> {
        self.spec.cluster_network.as_ref()
    }

    pub fn pod_cidrs(&self) -> Option<&[String]> {
        self.cluster_network()
            .and_then(|cn| cn.pods.as_ref())
            .map(|ranges| ranges.cidr_blocks.as_slice())
    }

    pub fn service_cidrs(&self) -> Option<&[String]> {
        self.cluster_network()
            .and_then(|cn| cn.pods.as_ref())
            .map(|ranges| ranges.cidr_blocks.as_slice())
    }

    /// GetIPFamily returns a ClusterIPFamily from the configuration provided.
    pub fn get_ip_family(&self) -> Result<ClusterIpFamily, InvalidIpFamily> {
        let pod_cidrs = self.pod_cidrs().unwrap_or_default();
        let service_cidrs = self.service_cidrs().unwrap_or_default();

        if pod_cidrs.is_empty() && service_cidrs.is_empty() {
            return Ok(ClusterIpFamily::Ipv4IpFamily);
        }

        let pods_family = ClusterIpFamily::ip_family_for_cidr_strings(pod_cidrs)?;
        let services_family = ClusterIpFamily::ip_family_for_cidr_strings(service_cidrs)?;

        if pods_family == services_family {
            Ok(pods_family)
        } else {
            Err(InvalidIpFamily::IpFamilyMismatch)
        }
    }
}

impl fmt::Display for NetworkRanges {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "{}", self.cidr_blocks.join(","))
    }
}

impl ClusterStatus {
    pub fn phase(&self) -> ClusterPhase {
        self.phase.unwrap_or(ClusterPhase::Unknown)
    }
}

impl ApiEndpoint {
    /// IsZero returns true if both host and port are zero values.
    pub fn is_zero(&self) -> bool {
        self.host.is_empty() && self.port == 0
    }

    /// IsValid returns true if both host and port are non-zero values.
    pub fn is_valid(&self) -> bool {
        !self.host.is_empty() && self.port != 0
    }
}

impl fmt::Display for ApiEndpoint {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "{}:{}", self.host, self.port)
    }
}

==> k8s-cluster-api-0.0.7.crate: k8s-cluster-api-0.0.7/src/v1beta1/cluster/impls.rs <==
use std::fmt;

use super::*;

impl Cluster {
    pub fn infrastructure_ready(&self) -> bool {
        self.status
            .as_ref()
            .and_then(|status| status.infrastructure_ready)
            .unwrap_or_default()
    }

    pub fn control_plane_ready(&self) -> bool {
        self.status
            .as_ref()
            .and_then(|status| status.control_plane_ready)
            .unwrap_or_default()
    }

    pub fn phase(&self) -> ClusterPhase {
        self.status
            .as_ref()
            .map_or(ClusterPhase::Unknown, |status| status.phase())
    }

    pub fn conditions(&self) -> Option<&Conditions> {
        self.status
            .as_ref()
            .and_then(|status| status.conditions.as_ref())
    }

    pub fn conditions_mut(&mut self) -> Option<&mut Conditions> {
        self.status
            .as_mut()
            .and_then(|status| status.conditions.as_mut())
    }

    pub fn cluster_network(&self) -> Option<&ClusterNetwork> {
        self.spec.cluster_network.as_ref()
    }

    pub fn pod_cidrs(&self) -> Option<&[String]> {
        self.cluster_network()
            .and_then(|cn| cn.pods.as_ref())
            .map(|ranges| ranges.cidr_blocks.as_slice())
    }

    pub fn service_cidrs(&self) -> Option<&[String]> {
        self.cluster_network()
            .and_then(|cn| cn.pods.as_ref())
            .map(|ranges| ranges.cidr_blocks.as_slice())
    }

    /// GetIPFamily returns a ClusterIPFamily from the configuration provided.
    pub fn get_ip_family(&self) -> Result<ClusterIpFamily, InvalidIpFamily> {
        let pod_cidrs = self.pod_cidrs().unwrap_or_default();
        let service_cidrs = self.service_cidrs().unwrap_or_default();

        if pod_cidrs.is_empty() && service_cidrs.is_empty() {
            return Ok(ClusterIpFamily::Ipv4IpFamily);
        }

        let pods_family = ClusterIpFamily::ip_family_for_cidr_strings(pod_cidrs)?;
        let services_family = ClusterIpFamily::ip_family_for_cidr_strings(service_cidrs)?;

        if pods_family == services_family {
            Ok(pods_family)
        } else {
            Err(InvalidIpFamily::IpFamilyMismatch)
        }
    }
}

impl fmt::Display for NetworkRanges {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "{}", self.cidr_blocks.join(","))
    }
}

impl ClusterStatus {
    pub fn phase(&self) -> ClusterPhase {
        self.phase.unwrap_or(ClusterPhase::Unknown)
    }
}

impl ApiEndpoint {
    /// IsZero returns true if both host and port are zero values.
    pub fn is_zero(&self) -> bool {
        self.host.is_empty() && self.port == 0
    }

    /// IsValid returns true if both host and port are non-zero values.
    pub fn is_valid(&self) -> bool {
        !self.host.is_empty() && self.port != 0
    }
}

impl fmt::Display for ApiEndpoint {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "{}:{}", self.host, self.port)
    }
}
